@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -21,13 +21,12 @@
 
 #include "contactselecttypecombobox.h"
 #include <KLocalizedString>
-
+#include <QDebug>
 using namespace ContactEditor;
 
 ContactSelectTypeCombobox::ContactSelectTypeCombobox(QWidget *parent)
     : ContactEditor::ContactEditorComboBox(parent)
 {
-    initialize();
 }
 
 ContactSelectTypeCombobox::~ContactSelectTypeCombobox()
