@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -34,9 +34,8 @@ public:
     ~ContactSelectTypeCombobox();
 
     QStringList selectTypeList() const;
-
+    virtual void initialize();
 private:
-    void initialize();
     QStringList mSelectType;
 };
 }
